@@ -133,21 +133,30 @@ static gboolean delayed_open_location (OpenLocation *ol) {
 void app_set_playing (Application *app, int p) {
     app->playing = p;
     if (PLAYING == p) {
+        gtk_widget_hide (GTK_WIDGET (app->tb_open));
         gtk_widget_show (GTK_WIDGET (app->tb_prev));
         gtk_widget_hide (GTK_WIDGET (app->tb_play));
         gtk_widget_show (GTK_WIDGET (app->tb_pause));
         gtk_widget_show (GTK_WIDGET (app->tb_next));
         gtk_widget_hide (GTK_WIDGET (app->tb_save));
         gtk_widget_show (GTK_WIDGET (app->tb_stop));
+        gtk_widget_show (GTK_WIDGET (app->tb_progress));
+        gtk_widget_hide (GTK_WIDGET (app->tb_location));
+        gtk_widget_hide (GTK_WIDGET (app->tb_go));
     } else {
         gtk_widget_hide (GTK_WIDGET (app->tb_pause));
         gtk_widget_show (GTK_WIDGET (app->tb_play));
         if (NOT_PLAYING == p) {
+            gtk_widget_show (GTK_WIDGET (app->tb_open));
             gtk_widget_hide (GTK_WIDGET (app->tb_prev));
             gtk_widget_hide (GTK_WIDGET (app->tb_stop));
             gtk_widget_hide (GTK_WIDGET (app->tb_next));
             gtk_widget_show (GTK_WIDGET (app->tb_save));
+            gtk_widget_show (GTK_WIDGET (app->tb_location));
+            gtk_widget_show (GTK_WIDGET (app->tb_go));
+            gtk_widget_hide (GTK_WIDGET (app->tb_progress));
         } else {
+            gtk_widget_hide (GTK_WIDGET (app->tb_open));
             gtk_widget_show (GTK_WIDGET (app->tb_prev));
             gtk_widget_show (GTK_WIDGET (app->tb_next));
             gtk_widget_hide (GTK_WIDGET (app->tb_save));
@@ -173,25 +182,12 @@ static void _app_setup_window (GtkWidget * w, Application *app) {
 
 void app_full_screen (Application *app) {
     if (!app->fullscreen) {
-        if (!app->window_fullscreen) {
-            HildonWindow *win = HILDON_WINDOW (hildon_stackable_window_new ());
-            app->window_fullscreen = GTK_WINDOW (win);
-            hildon_program_add_window (HILDON_PROGRAM (app->program), win);
-            /*g_signal_connect (G_OBJECT (win), "map-event",
-                    GTK_SIGNAL_FUNC (cbViewAreaFullscreenMapped), app);
-            g_signal_connect (G_OBJECT (win), "unmap",
-                    GTK_SIGNAL_FUNC (cbViewAreaFullscreenUnmapped), app);*/
-            g_signal_connect (G_OBJECT (win), "destroy",
-                    GTK_SIGNAL_FUNC (cb_fullscreen_destoyed), app);
-            g_signal_connect (G_OBJECT (win), "key-press-event",
-                    GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
-            gtk_widget_realize (GTK_WIDGET (app->window_fullscreen));
-        }
         app->fullscreen = true;
-
-        gtk_widget_reparent (app->view_area, GTK_WIDGET (app->window_fullscreen));
-        gtk_widget_show_all (GTK_WIDGET (app->window_fullscreen));
-        cbViewAreaFullscreenMapped (GTK_WIDGET (app->window_fullscreen), NULL, app);
+        gtk_widget_hide (app->info_area);
+        gtk_widget_hide (app->playlist_area);
+        gtk_widget_hide (app->toolbar_area);
+        gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 410);
+        gtk_window_fullscreen (app->window);
         app_update_screen_blanking (app);
     }
 }
@@ -199,12 +195,14 @@ void app_full_screen (Application *app) {
 void app_normal_screen (Application *app) {
     if (app->fullscreen) {
         app->fullscreen = false;
-
-        gtk_widget_reparent (app->view_area, app->view_base);
-        gtk_container_resize_children (GTK_CONTAINER (app->view_base));
-
-        hildon_window_stack_pop_1 (hildon_window_stack_get_default ());
-        cbViewAreaFullscreenUnmapped (GTK_WIDGET (app->window_fullscreen), app);
+        gtk_window_unfullscreen (app->window);
+        gtk_widget_show (app->playlist_area);
+        gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 354);
+        gtk_widget_show (app->toolbar_area);
+        if (app->controls_timer) {
+            g_source_remove (app->controls_timer);
+            app->controls_timer = 0;
+        }
     }
     app_update_screen_blanking (app);
 }
@@ -221,6 +219,77 @@ void app_store_save_directory (Application *app, gchar *path) {
     }
 }
 
+static gboolean _controlsTimeout (Application *app)
+{
+    gtk_widget_hide (app->video_stop);
+    if (app->fullscreen)
+        gtk_widget_hide (app->toolbar_area);
+    gtk_widget_hide (app->title_area);
+    app->controls_timer = 0;
+    return FALSE;
+}
+
+void app_show_controls (Application *app)
+{
+    if (app->fullscreen) {
+        if (app->controls_timer)
+            g_source_remove (app->controls_timer);
+        app->controls_timer = g_timeout_add (2000, (GSourceFunc) _controlsTimeout, app);
+        gtk_widget_show_all (app->video_stop);
+        gtk_widget_show (app->toolbar_area);
+    }
+}
+
+static void _appShowTitle (Application *app)
+{
+    GValue icon = { 0 , };
+    GValue text = { 0 , };
+    if (playlist_selected (app, &icon, &text)) {
+        GdkPixbuf *pix = (GdkPixbuf *) g_value_get_object (&icon);
+        const gchar *val = g_value_get_string (&text);
+        GtkWidget *img = NULL;
+        /*if (pix)
+            img = gtk_image_new_from_pixbuf (pix);*/
+        if (!app->video_title) {
+            app->video_title = gtk_tool_button_new (img, val);
+            gtk_fixed_put(GTK_FIXED (app->title_area),
+                    GTK_WIDGET (app->video_title), 0, 0);
+            gtk_widget_show_all (GTK_WIDGET (app->video_title));
+        } else {
+            gtk_tool_button_set_label (GTK_TOOL_BUTTON (app->video_title), val);
+            gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (app->video_title), img);
+        }
+        g_value_unset (&icon);
+        g_value_unset (&text);
+        gtk_widget_set_size_request (GTK_WIDGET(app->video_title), 600, 70);
+        gtk_widget_show (app->title_area);
+    }
+}
+
+static gboolean _titleTimeout (Application *app)
+{
+    if (!app->controls_timer)
+        gtk_widget_hide (app->title_area);
+    app->title_timer = 0;
+    return FALSE;
+}
+
+void app_selection_changed (Application *app)
+{
+    if (app->fullscreen && !app->controls_timer) {
+        if (app->title_timer)
+            g_source_remove (app->title_timer);
+        app->title_timer = g_timeout_add (2000, (GSourceFunc) _titleTimeout, app);
+    }
+    _appShowTitle (app);
+}
+
+static void _appShowPlaylistNav (GtkButton * button, Application *app)
+{
+    app_show_controls (app);
+    _appShowTitle (app);
+}
+
 static void callback_file_open (GtkButton * button, Application * app) {
     gchar *filename = NULL;
     filename = app_file_chooser(app, app->save_folder, GTK_FILE_CHOOSER_ACTION_OPEN);
@@ -269,21 +338,6 @@ gboolean locationbarKeyEvent (GtkWidget *w, GdkEventKey *e, Application *app) {
     return false;
 }
 
-static bool first_time_exposed;
-
-static
-bool cb_window_expose (GtkWidget *w, GdkEventExpose *ev, Application *app) {
-    if (!first_time_exposed) {
-        first_time_exposed = true;
-        gtk_paned_set_position (app->hsplit_view, HSPLIT);
-        gtk_paned_set_position (app->vsplit_view, VSPLIT);
-        gtk_widget_hide (GTK_WIDGET (app->tb_progress));
-        gtk_widget_hide (GTK_WIDGET (app->tb_item_playlist_commit));
-        gtk_widget_hide (app->info_viewport);
-    }
-    return false;
-}
-
 static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
     (void)gps;
     app->top_most_window = hildon_window_get_is_topmost (HILDON_WINDOW (app->window));
@@ -296,15 +350,15 @@ static void windowTopMost (GObject * self, GParamSpec *gps, Application * app) {
 /* Create the menu items needed for the main view */
 static void create_toolbar (Application * app) {
     /* Create needed variables */
-    GtkToolItem *tb_open;
-    GtkToolItem *tb_separator;
     GtkWidget *vbox;
+    GtkListStore *model;
+    GtkTreeIter iterator;
 
     /* Create toolbar */
     app->main_toolbar = gtk_toolbar_new();
 
     /* Create toolbar button items */
-    tb_open = gtk_tool_button_new_from_stock (GTK_STOCK_OPEN);
+    app->tb_open = gtk_tool_button_new_from_stock (GTK_STOCK_OPEN);
     app->tb_prev = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PREVIOUS);
     app->tb_play = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
     app->tb_pause = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE);
@@ -319,8 +373,7 @@ static void create_toolbar (Application * app) {
     /* Create toolbar combobox item */
     app->tb_location = gtk_tool_item_new();
     app->tb_progress = gtk_tool_item_new();
-    GtkListStore * model = gtk_list_store_new (1, G_TYPE_STRING);
-    GtkTreeIter iterator;
+    model = gtk_list_store_new (1, G_TYPE_STRING);
     gtk_list_store_append (model, &iterator);
     gtk_list_store_set (model, &iterator, 0, "", -1);
     app->location_bar = gtk_combo_box_entry_new_with_model (
@@ -338,16 +391,12 @@ static void create_toolbar (Application * app) {
     gtk_container_add (GTK_CONTAINER (app->tb_location), vbox);
     gtk_container_add (GTK_CONTAINER (app->tb_progress), app->progress_bar);
 
-    /* Create separator */
-    tb_separator = gtk_separator_tool_item_new();
-
     /* Add all items to toolbar */
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_location, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_progress, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_go, -1);
-    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_open, -1);
+    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_open, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), GTK_TOOL_ITEM (app->tb_item_playlist_commit), -1);
-    gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), tb_separator, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_prev, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_play, -1);
     gtk_toolbar_insert(GTK_TOOLBAR(app->main_toolbar), app->tb_pause, -1);
@@ -358,7 +407,7 @@ static void create_toolbar (Application * app) {
     /* Add signal lister to "Close" button */
     g_signal_connect (G_OBJECT (app->tb_go), "clicked",
         G_CALLBACK (callback_file_go), app);
-    g_signal_connect (G_OBJECT (tb_open), "clicked",
+    g_signal_connect (G_OBJECT (app->tb_open), "clicked",
         G_CALLBACK(callback_file_open), app);
     g_signal_connect (G_OBJECT (app->tb_prev), "clicked",
         G_CALLBACK (cb_playlist_prev), app->control);
@@ -379,11 +428,12 @@ static void create_toolbar (Application * app) {
 
     /* Add toolbar to 'vbox' of HildonAppView */
     gtk_widget_show_all (GTK_WIDGET (app->main_toolbar));
+    gtk_widget_hide (GTK_WIDGET (app->tb_item_playlist_commit));
     gtk_widget_hide (GTK_WIDGET (app->tb_progress));
     gtk_widget_hide (GTK_WIDGET (app->tb_pause));
     gtk_widget_hide (GTK_WIDGET (app->tb_stop));
-    hildon_window_add_toolbar (HILDON_WINDOW (app->window),
-            GTK_TOOLBAR(app->main_toolbar));
+    gtk_widget_set_size_request (app->main_toolbar, 800, 70);
+    gtk_fixed_put(GTK_FIXED (app->toolbar_area), app->main_toolbar, 0, 0);
 }
 
 static GtkWidget *makeMenuButton (const char *text) {
@@ -526,10 +576,10 @@ void cbPluginRemoved (GtkSocket *socket, Application *app) {
 int main (int argc, char* argv[]) {
     HildonProgram *program;
     HildonWindow *main_window;
-    GtkWidget *scroll_window;
     PangoContext *pango_cxt;
     PangoFontDescription *pfd;
     Application *app;
+    GtkWidget *video_stop;
 
     g_thread_init (NULL);
     /* Create needed variables */
@@ -557,7 +607,7 @@ int main (int argc, char* argv[]) {
     gtk_init (&argc, &argv);
     gtk_rc_parse_string ("style \"kmplayer-touchlist\" = \"fremantle-touchlist\" {\n"
             "  GtkTreeView::row-height = 50\n"
-            "} widget_class \"*.<GtkPaned>.<HildonPannableArea>.<GtkTreeView>\" "
+            "} widget_class \"*.<GtkFixed>.<HildonPannableArea>.<GtkTreeView>\" "
             "style \"kmplayer-touchlist\"");
 
     /* Create the hildon application and setup the title */
@@ -569,43 +619,57 @@ int main (int argc, char* argv[]) {
         gtk_infoprint (GTK_WINDOW (app->app), "Failed to initialize");
         return 1;
     }*/
-    /* Create HildonAppView and set it to HildonApp */
     main_window = HILDON_WINDOW (hildon_stackable_window_new ());
     app->window = GTK_WINDOW (main_window);
     hildon_program_add_window (program, main_window);
 
-    /* Add example label to appview */
-    app->hsplit_view = GTK_PANED (gtk_hpaned_new ());
-    scroll_window = hildon_pannable_area_new ();
-    g_object_set (G_OBJECT (scroll_window),
-            "mov-mode", HILDON_MOVEMENT_MODE_BOTH, 0);
-    app->playlist_view = createTreeView (app);
-    gtk_container_add (GTK_CONTAINER (scroll_window), app->playlist_view);
-    app->vsplit_view = GTK_PANED (gtk_vpaned_new ());
-    app->isplit_view = gtk_vbox_new (false, 0);
-    gtk_paned_pack1 (app->hsplit_view, scroll_window, true, false);
-    gtk_paned_pack2 (app->hsplit_view, GTK_WIDGET (app->vsplit_view), true, false);
-    app->view_base = gtk_alignment_new (0, 0, 1, 1);
+    app->window_area = gtk_fixed_new ();
     app->view_area = gtk_fixed_new ();
-    app->video_socket = gtk_socket_new ();
+    app->video_stop = gtk_fixed_new ();
+    app->title_area = gtk_fixed_new ();
+    app->playlist_area = hildon_pannable_area_new ();
+    app->toolbar_area = gtk_fixed_new ();
+    app->info_area = gtk_vbox_new (false, 0);
+
+    gtk_widget_set_size_request (app->video_stop, 70, 70);
+    gtk_widget_set_size_request (app->title_area, 600, 70);
+    gtk_widget_set_size_request (app->playlist_area, 800, 354);
+    gtk_widget_set_size_request (app->toolbar_area, 800, 70);
+    gtk_widget_set_size_request (app->info_area, 400, 140);
+
     gtk_fixed_set_has_window (GTK_FIXED (app->view_area), TRUE);
+    gtk_fixed_set_has_window (GTK_FIXED (app->video_stop), TRUE);
+    gtk_fixed_set_has_window (GTK_FIXED (app->title_area), TRUE);
+    gtk_fixed_set_has_window (GTK_FIXED (app->toolbar_area), TRUE);
+
+    g_object_set (G_OBJECT (app->playlist_area),
+            "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
+    app->playlist_view = createTreeView (app);
+    gtk_container_add (GTK_CONTAINER (app->playlist_area), app->playlist_view);
+    gtk_widget_set_size_request (app->view_area, 800, 480);
+    app->video_socket = gtk_socket_new ();
     gtk_widget_set_size_request (app->video_socket, 50, 50);
     gtk_fixed_put (GTK_FIXED (app->view_area), app->video_socket, -60, -60);
-    gtk_container_add (GTK_CONTAINER (app->view_base), app->view_area);
     _app_setup_window (app->view_area, app);
+
+    video_stop = GTK_WIDGET (gtk_tool_button_new (gtk_image_new_from_icon_name(
+                    "general_close", HILDON_ICON_SIZE_TOOLBAR), NULL));
+
+    gtk_fixed_put (GTK_FIXED (app->video_stop), video_stop, 0, 0);
+
+    g_signal_connect (G_OBJECT (video_stop), "clicked",
+            G_CALLBACK (cb_playlist_stop), app->control);
+
     g_signal_connect (app->program, "notify::is-topmost",
         GTK_SIGNAL_FUNC (programTopMost), app);
     g_signal_connect (G_OBJECT (main_window), "delete-event",
         GTK_SIGNAL_FUNC (cb_mainview_delete), app);
-    g_signal_connect (G_OBJECT (main_window), "expose-event",
-        GTK_SIGNAL_FUNC (cb_window_expose), app);
     g_signal_connect (G_OBJECT (main_window), "notify::is-topmost",
         GTK_SIGNAL_FUNC (windowTopMost), app);
     g_signal_connect (G_OBJECT (app->video_socket), "plug-added",
             GTK_SIGNAL_FUNC (cbPluginAdded), app);
     g_signal_connect (G_OBJECT (app->video_socket), "plug-removed",
             GTK_SIGNAL_FUNC (cbPluginRemoved), app);
-    gtk_paned_add1 (app->vsplit_view, app->view_base);
     app->infopanel_view = gtk_text_view_new ();
     app->info_viewport = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (app->info_viewport),
@@ -615,23 +679,28 @@ int main (int argc, char* argv[]) {
         (GTK_SCROLLED_WINDOW (app->info_viewport), app->infopanel_view);
     g_object_set (G_OBJECT (app->infopanel_view),
             "cursor-visible", FALSE, "editable", FALSE,
-            "wrap-mode", GTK_WRAP_WORD, 0L);
+            "wrap-mode", GTK_WRAP_WORD, NULL);
     pango_cxt = gtk_widget_get_pango_context (app->infopanel_view);
     pfd = pango_font_description_from_string ("Sans 12");
     gtk_widget_modify_font (app->infopanel_view, pfd);
     app->html_infopanel_view = gtk_html_new ();
     gtk_container_add (GTK_CONTAINER (app->html_viewport),
             app->html_infopanel_view);
-    gtk_container_add (GTK_CONTAINER (app->isplit_view), app->info_viewport);
-    gtk_container_add (GTK_CONTAINER (app->isplit_view), app->html_viewport);
+    gtk_container_add (GTK_CONTAINER (app->info_area), app->info_viewport);
+    gtk_container_add (GTK_CONTAINER (app->info_area), app->html_viewport);
     g_object_ref (app->info_viewport);
     g_object_ref (app->html_viewport);
-    gtk_paned_add2 (app->vsplit_view, GTK_WIDGET (app->isplit_view));
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->view_area, 0, 0);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->video_stop, 730, 0);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->title_area, 100, 0);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->playlist_area, 0, 0);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->toolbar_area, 0, 354);
+    gtk_fixed_put (GTK_FIXED (app->window_area), app->info_area, 400, 214);
     /*g_object_set (G_OBJECT (split_view->child1),
             "resize", TRUE, "shrink", TRUE, 0L);
     g_object_set (G_OBJECT (split_view->child2),
             "resize", TRUE, "shrink", TRUE, 0L);*/
-    gtk_container_add (GTK_CONTAINER (main_window), GTK_WIDGET (app->hsplit_view));
+    gtk_container_add (GTK_CONTAINER (main_window), app->window_area);
     /* Create menu for view */
     create_menu (app);
     create_toolbar (app);
@@ -648,10 +717,14 @@ int main (int argc, char* argv[]) {
             GTK_SIGNAL_FUNC (locationbarLostFocus), app);
     g_signal_connect (G_OBJECT (main_window), "key-press-event",
             GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
-    /* Begin the main application */
-    gtk_paned_set_position (app->hsplit_view, HSPLIT);
-    gtk_paned_set_position (app->vsplit_view, VSPLIT);
-    gtk_widget_show_all (GTK_WIDGET (main_window));
+
+    gtk_widget_show_all (app->view_area);
+    gtk_widget_show_all (app->playlist_area);
+    gtk_widget_show_all (app->html_viewport);
+    gtk_widget_show_all (app->infopanel_view);
+    gtk_widget_show (app->toolbar_area);
+    gtk_widget_show (app->window_area);
+    gtk_widget_show (GTK_WIDGET (app->window));
 
     osso_mime_set_cb (app->osso_context, cb_openUrls, app);
     if (osso_rpc_set_cb_f (app->osso_context,
