@@ -25,12 +25,17 @@
 #include <expat.h>
 #endif
 #include "kmplayerplaylist.h"
+#ifdef KMPLAYER_XML_FORMATS
 #include "kmplayer_asx.h"
 #include "kmplayer_atom.h"
 #include "kmplayer_rp.h"
 #include "kmplayer_rss.h"
 #include "kmplayer_smil.h"
 #include "kmplayer_xspf.h"
+#else
+#include <vector>
+typedef std::vector <KMPlayer::String> StringList;
+#endif
 #include "actor.h"
 
 #ifdef SHAREDPTR_DEBUG
@@ -45,6 +50,7 @@ using namespace KMPlayer;
 
 Node * KMPlayer::fromXMLDocumentTag (NodePtr & d, const String & tag) {
     const char * const name = (const char *) tag;
+#ifdef KMPLAYER_XML_FORMATS
     if (!strcmp (name, "smil"))
         return new SMIL::Smil (d);
     else if (!strcasecmp (name, "asx"))
@@ -57,7 +63,9 @@ Node * KMPlayer::fromXMLDocumentTag (NodePtr & d, const String & tag) {
         return new ATOM::Feed (d);
     else if (!strcasecmp (name, "playlist"))
         return new XSPF::Playlist (d);
-    else if (!strcasecmp (name, "url"))
+    else
+#endif
+    if (!strcasecmp (name, "url"))
         return new GenericURL (d, String ());
     else if (!strcasecmp (name, "mrl") ||
             !strcasecmp (name, "document"))
@@ -236,7 +244,8 @@ void Node::undefer () {
             setState (state_began);
         } else {
             setState (state_activated);
-            activate ();
+            // don't call activate; if this is the document, it will start again
+            //activate ();
         }
     } else
         warningLog() <<"Node::undefer () call on not defered element"<< endl;
@@ -995,6 +1004,10 @@ int diffTime (const struct timeval & tv1, const struct timeval & tv2) {
 }
 
 static inline void addTime (struct timeval & tv, int ms) {
+    if (ms >= 1000) {
+        tv.tv_sec += ms / 1000;
+        ms %= 1000;
+    }
     tv.tv_sec += (tv.tv_usec + ms*1000) / 1000000;
     tv.tv_usec = (tv.tv_usec + ms*1000) % 1000000;
 }
@@ -1050,6 +1063,9 @@ KDE_NO_CDTOR_EXPORT UpdateEvent::UpdateEvent (Document *doc, unsigned int skip)
     cur_event_time = doc->last_event_time;
 }
 
+PostponedEvent::PostponedEvent (bool postponed)
+    : is_postponed (postponed) {}
+
 //-----------------------------------------------------------------------------
 /*static inline void subtractTime (struct timeval & tv, int ms) {
     int sec = ms / 1000;
