@@ -690,6 +690,8 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
                 if (p && strstr (p, "play")) { // find a 'Start.*play' pattern
                     m_notify->setLoading (99);
                     handled = true;
+                    if (hasVideo ())
+                        m_notify->videoDetected ();
                 } else {
                     char * c = strstr (tok, "Cache fill:");
                     if (c) {
@@ -721,10 +723,12 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (UnixProcess *) {
                         } // else ignore, a second 'pause' cmd should follow
                     } else if (!strncmp (tok + 3, "VIDEO_WIDTH", 11)) {
                         m_width = (int) strtof (tok + 15, 0L);
+                        m_notify->videoDetected ();
                         if (m_height > 0)
                             updateAspects ();
                     } else if (!strncmp (tok + 3, "VIDEO_HEIGHT", 12)) {
                         m_height = (int) strtof (tok + 16, 0L);
+                        m_notify->videoDetected ();
                         if (m_width > 0)
                             updateAspects ();
                     } else if (!strncmp (tok + 3, "VIDEO_ASPECT", 12)) {
