@@ -41,7 +41,6 @@ typedef struct _NPPluginLib {
 
 
 typedef struct _NSNotify {
-    void (* embedded) (void *ndata);
     void (* setDimension) (void *ndata, int w, int h);
     void (* getUrl) (void *inst, uint32_t stream,
             const char *url, const char *target,
@@ -61,6 +60,7 @@ void nppStreamInfo (uint32_t stream, const char *mime, unsigned long length);
 void *nppInstanceOpen (const char *mime, uint16_t argc,
         char *argn[], char *argv[], void *ndata, NSNotify *notify);
 void nppInstanceWindowParent (void *inst, void * wid);
+void nppInstanceTopUrl (const char *url);
 void nppInstanceStart (const char *url, const char *mime, void *inst);
 void nppInstanceWindowDimension (void *inst, int x, int y, int w, int h);
 void nppInstanceClose (void *inst);
